@@ -33,9 +33,10 @@
 #  define KI18N_DEPRECATED_NO_EXPORT KI18N_NO_EXPORT KI18N_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KI18N_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KI18N_NO_DEPRECATED
+#    define KI18N_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
